OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Защита на лични данни",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центърът за поверителност ви показва къде се съхраняват вашите данни и кой може да има достъп до тях, или защото сте споделили с тях, или защото те са администратори.",
    "Remove external {propertyName} admin" : "Премахване на външен администратор {propertyName}",
    "Add external admin" : "Добавяне на външен администратор",
    "Name of external admin" : "Име на външен администратор",
    "Adapt encryption" : "Адаптиране на криптирането",
    "This server is using full-disk-encryption." : "Този сървър използва шифроване на пълен диск.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Базовото ви хранилище е криптирано с помощта на {linkkopen} сървърно криптиране {linkclose} с главен ключ. Това означава, че администраторите имат достъп до вашите файлове, но не и да четат съдържанието им.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Вашите файлове във външни хранилища може да бъдат криптирани чрез {linkopen}криптиране от страна на сървъра ↗{linkclose} с главен ключ въз основа на тяхната конфигурация.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Базовото ви хранилище е криптирано с помощта на {linkopen} сървърно криптиране {linkclose} с индивидуален потребителски ключ. Това означава, че администраторите имат достъп до вашите файлове, но не и да четат съдържанието им.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Вашите файлове във външни хранилища може да бъдат криптирани чрез {linkopen}криптиране от страна на сървъра ↗{linkclose} с индивидуален ключ въз основа на тяхната конфигурация.",
    "Additionally, this server is protected with full-disk-encryption." : "Освен това този сървър е защитен с пълно дисково криптиране.",
    "This server is protected with full-disk-encryption." : "Този сървър е криптиран",
    "Your files are not protected by encryption." : "Вашите файлове не са защитени чрез криптиране.",
    "Your data is located in:" : "Вашите данни се намират в:",
    "The admin has not selected the location of the server yet." : "Администраторът все още не е избрал местоположението на сървъра.",
    "Change data location" : "Промяна на местоположението на данните",
    "Please select a region" : "Моля, изберете регион",
    "You don't have any shares with individual users." : "Нямате никакви споделяния с отделни потребители.",
    "Somaliland" : "Сомалиленд",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединени арабски емирства",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аржентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгия",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "България",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei" : "Бруней",
    "Bolivia" : "Боливия",
    "Bonaire, Sint Eustatius and Saba" : "отвъдморски територии на Нидерландия",
    "Brazil" : "Бразилия",
    "Bahamas" : "Бахамски острови",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "остров Буве",
    "Botswana" : "Ботсуана",
    "Belarus" : "Беларус",
    "Belize" : "Белийз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови строви (Кийлинг)",
    "Democratic Republic of the Congo" : "Демократична република Конго",
    "Central African Republic" : "Централноафриканска република",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Cote d'Ivoire" : "Кот д’Ивоар",
    "Cook Islands" : "Oстрови Кук",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "остров Рождество",
    "Cyprus" : "Кипър",
    "Czech" : "чешки",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominican Republic" : "Доминиканска република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естония",
    "Egypt" : "Египет",
    "West Sahara" : "Западна Сахара",
    "Eritrea" : "Еритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Етиопия",
    "Finland" : "Финландия",
    "Fiji" : "Фиджи",
    "Falkland Islands" : "Оландски острови",
    "Micronesia" : "Микронезия",
    "Faroe Islands" : "Фарьорски острови",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom" : "Обединено кралство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Френска Гвиана",
    "Guernsey" : "Гърнзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваториална Гвинея",
    "Greece" : "Гърция",
    "South Georgia and the South Sandwich Islands" : "Южна Джорджия и Южни Сандвичеви острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея Бисау",
    "Guyana" : "Гвиaна",
    "Honduras" : "Хондурас",
    "Hong Kong" : "Хонконг",
    "Heard Island and McDonald Islands" : "Хърд и Макдоналд",
    "Croatia" : "Хърватия",
    "Haiti" : "Хаити",
    "Hungary" : "Унгария",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британска индоокеанска територия",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кирибати",
    "Comores" : "Коморски острови",
    "Saint Kitts and Nevis" : "Сейнт Китс и Невис",
    "North Korea" : "Северна Корея",
    "South Korea" : "Северна Корея",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманови острови",
    "Kazakhstan" : "Казахстан",
    "Laos" : "лаоски",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сейнт Лусия",
    "Liechtenstein" : "Лихтенщайн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Либия",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova" : "Молдова",
    "Montenegro" : "Черна гора",
    "Saint Martin" : "Сен Мартен",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалови острови",
    "Macedonia" : "Северна Македония",
    "Mali" : "Мали",
    "Myanmar" : "Мианмар",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Мариански острови",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монсерат",
    "Malta" : "Малта",
    "Mauritius" : "Мавриций",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Нова Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Oстров Норфолк",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерландия",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нова Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Френска Полинезия",
    "Papua New Guinea" : "Папуа Нова Гвинея",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полша",
    "Saint Pierre and Miquelon" : "Сен Пиер и Микелон",
    "Pitcairn" : "Oстрови Питкерн",
    "Puerto Rico" : "Пуерто Рико",
    "Palestine" : "Палестина",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюнион",
    "Romania" : "Румъния",
    "Serbia" : "Сърбия",
    "Russia" : "Русия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудитска Арабия",
    "Solomon Islands" : "Соломонови острови",
    "Seychelles" : "Сейшелски острови",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Възнесение и Тристан да Куня",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Свалбард и Ян Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалия",
    "Suriname" : "Суринам",
    "South Sudan" : "Южен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипи",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten" : "Синт Мартен",
    "Syria" : "Сирия",
    "Swaziland" : "Свазиленд",
    "Turks and Caicos Islands" : "Търкс и Кайкос",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Френски южни и антарктически територии",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Източен Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan" : "Тайван",
    "Tanzania" : "Танзания",
    "Ukraine" : "Украйна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малки отдалечени острови на Съединените щати",
    "United States" : "Съединени щати /САЩ/",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Свети престол",
    "Saint Vincent and the Grenadines" : "Сейнт Винсънт и Гренадини",
    "Venezuela" : "Венецуела",
    "Virgin Islands (British)" : "Британски Вирджински острови",
    "Virgin Islands (U.S.)" : "Американски Вирджински острови",
    "Vietnam" : "Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майот",
    "South Africa" : "Южна Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Your %s account" : "Вашият %s профил",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Вашите данни представят кой сте и с тях лесно може да се злоупотреби. Ние от Nextcloud вярваме, че имате право да решите какво да се случи с вашите данни. Nextcloud защитава вашите права, както са дефинирани в Манифеста за потребителските данни!",
    "User Data Manifesto 2.0" : "Манифест за потребителски данни 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Дефиниране на основните права на хората да контролират собствените си данни в ерата на интернет",
    "Control" : "Control Center",
    "over user data access" : "над достъпа до потребителски данни",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Данните, изрично и доброволно качени от потребител, трябва да бъдат под максимален контрол на потребителя. Потребителите трябва да могат да решават на кого да предоставят директен достъп до техните данни и с кои права и лицензи трябва да се предостави такъв достъп.",
    "Knowledge" : "Знание",
    "of how the data is stored" : "за това как се съхраняват данните",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Когато данните се качват на определен доставчик на услуги, потребителите трябва да бъдат информирани къде този конкретен доставчик на услуги съхранява данните, колко дълго, под коя юрисдикция оперира конкретният доставчик на услуги и кои закони се прилагат.",
    "Freedom" : "Свобода",
    "to choose a platform" : "да изберете платформа",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Потребителите трябва винаги да могат да извличат своите данни от услугата по всяко време, без да търпят заключване от доставчик. За да се гарантира това, са необходими отворени стандарти за формати и протоколи.",
    "Learn more ↗" : "Научете повече ↗",
    "Where is your data?" : "Къде е информацията ви?",
    "Who has access to your data?" : "Кой има достъп до информацията?",
    "Administrators" : "Администратори",
    "People you shared with" : "Хора с които е споделено",
    "Privacy policy" : "Политика за поверителност",
    "Read the privacy policy." : "Прочетете политиката за поверителност",
    "Encryption" : "Криптиране",
    "Remove external admin" : "Премахване на външен администратор",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Домашното ви хранилище е криптирано чрез {linkopen}криптиране от страна на сървъра ↗{linkclose} с главен ключ.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Домашното ви хранилище е криптирано чрез {linkopen}криптиране от страна на сървъра ↗{linkclose} с индивидуален потребителски ключ."
},
"nplurals=2; plural=(n != 1);");
